.. _api_ref:

.. currentmodule:: phyid

Reference API
=============

.. contents:: **List of modules**
   :local:

.. _ref_calculate:

:mod:`phyid.calculate` - calculate PhiID
--------------------------------------------
.. automodule:: phyid.calculate
   :no-members:
   :no-inherited-members:

.. currentmodule:: phyid.calculate

.. autosummary::
   :template: function.rst
   :toctree: generated/

    phyid.calculate.calc_PhiID

.. _ref_measures:

:mod:`phyid.measures` - measures
--------------------------------------------
.. automodule:: phyid.measures
   :no-members:
   :no-inherited-members:

.. currentmodule:: phyid.measures

.. autosummary::
   :template: function.rst
   :toctree: generated/

    phyid.measures.local_entropy_mvn
    phyid.measures.local_entropy_binary
    phyid.measures.redundancy_mmi
    phyid.measures.double_redundacy_mmi
    phyid.measures.redundancy_ccs
    phyid.measures.double_redundacy_ccs

.. _ref_utils:

:mod:`phyid.utils` - utilities
--------------------------------------------
.. automodule:: phyid.utils
   :no-members:
   :no-inherited-members:

.. currentmodule:: phyid.utils

.. autosummary::
   :template: function.rst
   :toctree: generated/

    phyid.utils._binarize